@@ -4,7 +4,7 @@ use 5.008_005;
 use Kelp::Base 'Kelp::Module::Config';
 use Config::General;
 
-our $VERSION = '0.02';
+our $VERSION = '0.03';
 
 attr ext => 'conf';
 
@@ -44,7 +44,7 @@ __END__
 
 =head1 NAME
 
-Kelp::Module::Config::ConfigGeneral - L<Config::General> as config module for your Kelp applications.
+Kelp::Module::Config::ConfigGeneral - DEPRICATED !!!!!!!!! L<Config::General> as config module for your Kelp applications.
 
 =head1 SYNOPSIS
 
@@ -55,6 +55,9 @@ Kelp::Module::Config::ConfigGeneral - L<Config::General> as config module for yo
 
 =head1 DESCRIPTION
 
+DEPRICATED!!!
+Module has moved to L<Kelp::Module::Config::General>.
+
 This module provides support of L<Config::General> as your C<Kelp::Module::Config> module.
 
 L<Config::General> module is loaded with following configuration options:
